Page 12 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 12

Home

    deity was Marduk (Bel), a name given to Nimrod.
    Nimrod may have been the builder of the Tower of

    Babel. The temple of Marduk contained golden images
    of Bel and Ishtar including a human figure of solid gold
    18 feet high. Babylon had 53 temples, and 180 altars
    dedicated to Ishtar.

    Ishtar was worshiped as a moon-goddess. She was a
    deification of the sex passion and worshipping her
    required licentiousness. Sacred prostitution within her

    sanctuaries was a universal custom among the women of
    Babylon. Every maid, wife or widow had to officiate in
    these rites at least once in her lifetime . The prophet
    Isaiah gives us a good look into the heart and soul of
    Babylon in Isaiah chapter 47:

    8 Therefore hear now this, thou that art given to
    pleasures, that dwellest carelessly, that sayest in thine
    heart, I am, and none beside me....

    9 But these two things shall come upon thee in a
    moment in one day, the loss of children, and
    widowhood: they shall come upon thee in their
    perfection for the multitude of thy sorceries, and for the
    great abundance of thine enchantments.

    wn toa eoatoa sad a 1

    and

    Although Ancient Babylon was outwardly powerful
    she was inwardly corrupt, a condition that led to her
    downfall. As foretold by Isaiah and Jeremiah, the fall

    Ancient Babylon

    Babylon was a national center of idolatry. Its chief

    10 For thou hast trusted in thy wickedness: thou has

    said, None seeth me.